/***************************************************************************
 *   Copyright (C) 2009 by Stefan Bühler                                   *
 *   stbuehler@web.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef TORUSCHESSTESTGAME_H
#define TORUSCHESSTESTGAME_H

#include <QWidget>
#include <QSvgRenderer>
#include <QMainWindow>
#include <QSize>
#include <QStackedLayout>

#include "toruschess.h"
#include "piecelibrary.h"

#include "optiondlg.h"

#include "field2d.h"
#include "field3d.h"

/**
	@author Stefan Bühler <stbuehler@web.de>
*/
namespace toruschess {
	
	class GameWidget : public QMainWindow {
	Q_OBJECT
	public:
		GameWidget(QWidget *parent = 0);
		
		ViewMode viewMode() const { return m_viewMode; }
		
	public slots:
		void setViewMode(ViewMode viewMode);
		
	signals:
		void changedViewMode(ViewMode viewMode);
		
	private slots:
		void gameChanged(GameState state);
		
		void menuRestart();
		void menuOptions();
		
		void menuView2d();
		void menuView3d();
		void menuViewTorus();
		
	private:
		Game *m_game;
		OptionDlg *m_optionDlg;
		ViewMode m_viewMode;
		
		QStackedLayout *m_fieldsLayout;
		Field2D *m_field2d;
		Field3D *m_field3d;
		
		QAction *m_act_view_2d, *m_act_view_3d, *m_act_view_torus;
	};
}

#endif
