/***************************************************************************
 *   Copyright (C) 2009 by Stefan Bühler                                   *
 *   stbuehler@web.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef TORUSCHESSPIECELIBRARY_H
#define TORUSCHESSPIECELIBRARY_H

#include <QSvgRenderer>

#include <lib3ds/file.h>

/**
	@author Stefan Bühler <stbuehler@web.de>
*/
namespace toruschess {

	/** Handles texture/3ds loading from compiled-in Qt-Resource file
	  */
	class PieceLibrary : public QObject {
	Q_OBJECT
	public:
		PieceLibrary(QObject *parent);
		virtual ~PieceLibrary();
		
		/* one PieceLibrary instance manages one set of images with a specific size
		 */
		QSize pieceSize() const { return QSize(m_width, m_height); }
		QSize minPieceSize() const { return QSize(20, 20); }
		void setSize(int width, int height);
		
		/* just paint the 2d picture of the "place" figure */
		void paint(QPainter &pt, int place) const;
		/* just paint the 2d picture of the "place" figure into the given rect */
		void paint(QPainter &pt, int place, const QRect &rect) const;
		
		/* paint background of a field into the given rect */
		void paint_board(QPainter &pt, bool darkField, const QRect &rect) const;
		
		/* paint a 3d pawn */
		void paint_pawn();
		
	private:
		QSvgRenderer **m_pieces;
		QImage **m_buffers, **m_board;
		int m_width, m_height;
		
		Lib3dsFile *m_pawn;
	};

}

#endif
